/*  screen.css - MoinMoin Default Styles

Copyright (c) 2001, 2002, 2003 by Juergen Hermann
Modified by Nir Soffer (technical theme), Mauricio Hernandez (ruleta theme)
*/

/* content styles */

/* debug 
* {border: 1px dotted blue;}
*/

body {
    padding:0;
    border:0;
}

/* NOTE: original red color for the words when mouse is over
a:hover, h1 a:hover {color: #ff0000;}
*/
a:hover, h1 a:hover {color: #d0ff00;}

input {
    font-size: 1em;
    font-family: Arial, Lucida Grande, sans-serif;
}

textarea {
    font-size: 1em;
    font-family: monospace;
}

/* NOTE: original drop-down menu colors */
/*input[type=text], input[type=password], select, textarea {
    color: #cccccc;
    background: #17181A;
    border-color: #292E33;
    border-size: 1px;
}
*/

input[type=text], input[type=password], select, textarea {
    color: #009600;
    background: #001f05; /* dark green that also affects editing page big square */
    border-color: #026102;
    border-size: 1px;
}

.disabled {
    /* IE ignore disabled attribute, but at least show items in gray */
/* NOTE: original light green color for disabled menu options
    color: #941b1b;
*/
    color: #a6dba6;
}

/* user interface styles */

#header {
    background: url(../img/matrixmoin_header.png);
    margin: 0;
    padding: 0;
}

#logo {
    float: left;
    margin: 5px 10px;
    padding: 0;
    /* For text only logo */
    font-size: 22px;
    line-height: 1em;
    font-weight: bold;
}

#logo img {
    vertical-align: middle;
}

/* NOTE: Wiki name color */
#logo a {
    color: white; /* original was white; */
    text-decoration: none;
}

*[dir="rtl"] #logo {
    float: right;
}

#username {
    margin: 0 10px;
    padding: 8px 0 0 0;
    text-align: right;
    font-size: 12px;
    white-space: nowrap;
}

*[dir="rtl"] #username {
    text-align: left;
}

#username li {
    display: inline;
    padding: 0 2px;
}

#username li:before {
	content: "• ";
    color: #00af00;
}

#username li:first-child:before {
	content: "";
}

#searchform {
	float: right;
	margin: 5px 10px;
	padding: 0;
	white-space: nowrap;
	font-size: 13px;
}

*[dir="rtl"] #searchform {
	float: left;
}

#searchform form div {
    display: inline;
}

#pagetrail {
	clear: both;
	margin: 0;
	padding: 0 10px;
	font-size: 13px;
}

#pagetrail li {
	float: left;
	display: block;
	padding: 0 2px;
	margin: 0 0 5px 0;
}

*[dir="rtl"] #pagetrail {
	float: right;
}

/* XXX Warning: non-ascii characters! */
/* NOTE: these are small things placed after your visited pages */
#pagetrail li:after {
	content: " » ";
	color: #d0ff00;
}

*[dir="rtl"] #pagetrail li:after {
	content: " « ";
}

#navibar {
	clear: both;
	display: block;
	margin: 0;
	padding: 0 10px;
	font-size: 12px;
}

#navibar li {
	float: left;
	display: block;
	margin: 0 2px;
	padding: 4px 7px;
	border: 1px solid #00af00;
	border-bottom: none;
	white-space: nowrap;
}

*[dir="rtl"] #navibar li {
	float: right;
}

/* color for the navibar links */
#navibar li.wikilink {
	background: black;
}

#navibar li.userlink {
	                     /* #292E33; alternate 2 */
	background: black; /* original was dark grey #17181A; */ /* alternate 1 */
}

/* NOTE: the color for the Link inside the buttons of navibar */
#navibar a, #navibar a:visited {
	color: white; /* original was grey #CCCCCC; */
	text-decoration: none;    
}

/* NOTE: this is the color for the current page link */
#navibar li.current a {
	color: white;
	font-weight: bold;
}

/* NOTE: this is the green color when mouse is over the navibar links */
#navibar li:hover {
	background: #009400; /* original was #303030; */
}

#navibar li.current, #navibar li.current:hover {
	background: #003700; /* original red #cd0000; */
}

/* NOTE: this is the horizontal line across the page menu */
#pageline {
	clear: both;
	margin: 0;
	padding: 0;
	width: 100%;
	/* sync these values, line-height is needed for IE */
		height: 3px;
		line-height: 3px;
	border-bottom: 2px solid #002a05; /* original red #cd0000; */
        border-top: 1px solid #003700; /* original red #cd0000; */
	background: #004000; /* original grey #cd0000; */
}

.editbar {
	clear: both;
	margin: 0;
	padding: 0 8px;
	white-space: nowrap;
	height: 26px;
	background: black;
	font-size: 13px;
}

.editbar form, .editbar form div {
    display: inline;
	margin: 0;
}

.editbar li {
	float: left;
	display: block;
	padding: 0;
	margin: 2px 6px;
}

*[dir="rtl"] .editbar li {
	float: right;
}

#header .editbar {
	border-bottom: 1px dotted #a6dba6;
}

#footer .editbar {
	border-top: 1px dotted #a6dba6;
	border-bottom: 1px solid #a6dba6;
}

.editbar a, .editbar a:visited {color: #009400;} /* original was blue {color: #cd0000;} */

#message {
	clear: both;
	margin: 0;
	padding: 5px 10px;
	border-bottom: 1px solid #a6dba6;
	background: #004000; /* dark green */
}

#message p{
	margin: 5px 0;
	padding: 0;
	font-weight: bold;
}

#message div.buttons {
	font-weight: normal;
}

.dialog form {
    margin: 0 15px;
}

.dialog td {
    border: none;
    padding: 5px;
}

.dialog td.label {
    text-align: right;
    font-weight: bold;
    width: 25%;
}

*[dir="rtl"] .dialog td.label {
    text-align: left;
}

.dialog td.content input {
    width: 100%;
}

#page {
	background-color: black;
	margin: 0;
	padding: 10px 30px 20px 30px;
}

/* We use here dumb css1 ids because of IE suckiness */
#editor-textarea, #editor-comment {
    width: 100%;
}

#preview {
	border: 1px solid #a6dba6;
	padding: 10px 30px 20px 30px;
	background: url(../img/draft-matrix.png);
}

#footer {
	clear: both;
	margin: 0;
	padding: 0;
}

#credits, #version, #timings{
	margin: 5px 10px;
	padding: 0;
	text-align: center;
	font-size: 0.88em;
	color: #a6dba6;
	font-size: 12px;
}

#credits li, #timings li {
	display: inline;
	padding: 0 2px;
	margin: 0 4px;
}

#credits img {
	vertical-align: middle;
}

.diff {
	width:99%;
}

.diff-header {
	font-weight: bold;
}

.diff-title {
	background-color: #e01c2d; /* original was grey #C0C0C0; */
}

.diff-added {
	background-color: #E0FFE0;
	vertical-align: sub;
}

.diff-removed {
	background-color: #17181a; /* original was pale yellow #FFFFE0; */
	vertical-align: sub;
}

.diff-added span {
	background-color: #80FF80;
}

.diff-removed span {
	background-color: #f677ea;/* original was yellow #FFFF80; */
}
