/*  projection.css - MoinMoin Slide Styles

Copyright (c) 2003 by Juergen Hermann
*/

@import url("screen.css");

html {
    font-size: 20pt;
/* You can choose 4 diiferent backgrounds (0-1-2-3) for matrixmoin_projection */
/* just uncomment the line. */
/*    background: url(../img/matrixmoin_projection0.jpg); */
    background: url(../img/matrixmoin_projection1.jpg);
/*    background: url(../img/matrixmoin_projection2.jpg); */
/*    background: url(../img/matrixmoin_projection3.jpg); */
}

#page {
    background: none;
}

/* Page name */
h1 {
    font-size: 14pt;
    margin: 0;
    color: #606060;
}

/* Slide heading */
h2 {
    font-size: 32pt;
    margin-top: 0.5em;
    border-bottom: 4px dotted #009400;
}


/* Slide content */

#content {margin-left: 100pt;}
#content[dir="rtl"] {margin-left: 0; margin-right: 100pt;}

h3 { font-size: 24pt; }
h4 { font-size: 18pt; }
h5 { font-size: 16pt; }
h6 { font-size: 14pt; }

tt, pre { font-size: 18pt; }
sup, sub { font-size: 14pt; }

/* Navigation */

#navigation {
	position: fixed;
	bottom: 0;
	left: 0;
	right: 0;
	padding: 0;
	margin: 0;
	color: #606060;
	font-size: 13pt;
}

#navigation ul {
    margin: 0;
    padding: 6pt;
    text-align: center;
}

#navigation li {
    display: inline;
	margin: 0 2pt;
	padding: 0;
}

#navigation a {
 	text-decoration: none;
}

#navigation .current {
    color: white;
}

